#!/usr/bin/perl -w
use strict;

use Getopt::Long;
my ($printMatrix, $useSymmetry);
GetOptions(
	"print-matrix"	=> \$printMatrix,
	"use-symmetry"	=> \$useSymmetry,
)	or exit;

use Channel;

my %data;
my ($p, $user, $observ);

while(<>) {
	chomp;

	/Model checking:.*observ(\d+).*user(\d+)/ && do {
		$observ = $1;
		$user = $2;
		next;
	};

	/constants: p=(\d+(\.\d*)?)/ && do {
		$p = $1/100;
		next;
	};

	/^Result[^:]*: (\d(\.\d*)?)(E-(\d*))?$/ && do {
		my $res = $1;
		$res *=  10 ** (-$4)	if defined $4;

		$data{$p} = [] 				unless exists $data{$p};
		$data{$p}[$user-1] = []		unless exists $data{$p}[$user-1];
		$data{$p}[$user-1][$observ-1] = $res;
		next;
	};
}

use Data::Dumper;

my @sortp = sort { $a <=> $b } keys %data;
my $e = 0.000001;

#print "$_:  ", Dumper($data{$_})
#	for @sortp;
#exit;

for $p (@sortp) {
	my $matrix = $data{$p};
	my $chan = new Channel $data{$p};

	#print_matrix($matrix)
	print $chan->to_string
		if $printMatrix;

	# check that all rows add-up to 1
	my ($ok, $msg) = $chan->test_matrix;
	$ok	or die "WARNING: $msg\n";

	my $capacity;
	if($useSymmetry) {
		my $symmetric_part = [0..$chan->output_no-2];
		$capacity = $chan->capacity_partsym($symmetric_part);
	} else {
		($capacity) = $chan->capacity($e);
	}

	printf "%.6f   %.6f\n", $p, $capacity;
}



